#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_RROR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_RROR_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/rror.hpp>

#endif
